@@ -2,7 +2,7 @@ from .mlp import MLPLayer
 from .lstmp import LSTMPCell, LSTMP
 from .multi_lstmp import MultiLSTMP
 from .bert_tokenization import BertTokenizationLayer
-from .bert_layer import BertLayer
+from .bert_layer import BertLayer, BertPreprocessingLayer
 
 
 __all__ = [
