@@ -7,8 +7,7 @@ from tensorflow.keras.initializers import TruncatedNormal
 from official.modeling import activations
 
 from sknlp.vocab import Vocab
-from sknlp.layers.bert_layer import BertLayer, BertPreprocessingLayer
-from sknlp.layers.bert_tokenization import BertTokenizationLayer
+from sknlp.layers import BertTokenizationLayer, BertLayer, BertPreprocessingLayer
 
 from .text2vec import Text2vec
 
